# cleanNLP-python

This is a small Python package to support R package of the same name. The
scripts were originally included in the R package, but it is easier for
long-term support to include it as a seperate repository. See the
[main cleanNLP page](https://github.com/statsmaths/cleanNLP) for more information.
